@@ -81,11 +81,9 @@ def main():
     argspec['root_credentials_rotate_statements'] = dict(required=False, type='list', default=[])
     argspec['verify_connection'] = dict(required=False, type='bool', default=True)
     argspec['connection_details'] = dict(required=True, type='dict')
-
-    supports_check_mode = True
     required_one_of = [['config_file', 'connection_details']]
 
-    module = hashivault_init(argspec, supports_check_mode, required_one_of=required_one_of)
+    module = hashivault_init(argspec, supports_check_mode=True, required_one_of=required_one_of)
     result = hashivault_db_secret_engine_config(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -102,7 +100,6 @@ def hashivault_db_secret_engine_config(module):
     state = params.get('state')
     name = params.get('name')
     desired_state = dict()
-    changed = False
     exists = False
 
     # if config_file is set value from file
@@ -153,7 +150,7 @@ def hashivault_db_secret_engine_config(module):
 
     # if configs dont match and checkmode is off, complete the change
     if changed and state == 'present' and not module.check_mode:
-        result = client.secrets.database.configure(name=name, mount_point=mount_point, **desired_state)
+        client.secrets.database.configure(name=name, mount_point=mount_point, **desired_state)
     elif changed and state == 'absent' and not module.check_mode:
         client.secrets.database.delete_connection(name=name, mount_point=mount_point)
 
