@@ -5,7 +5,6 @@ from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
 import json
-from ast import literal_eval
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
@@ -92,9 +91,7 @@ def main():
     argspec['renew_statements'] = dict(required=False, type='list', default=[])
     argspec['db_name'] = dict(required=False, type='str')
 
-    supports_check_mode = True
-
-    module = hashivault_init(argspec, supports_check_mode)
+    module = hashivault_init(argspec, supports_check_mode=True)
     result = hashivault_db_secret_engine_role(module)
     if result.get('failed'):
         module.fail_json(**result)
