@@ -101,7 +101,7 @@ def hashivault_oidc_auth_method_config(module):
     current_state = dict()
     exists = False
 
-    token = params['token']
+    token = params.get('token', client.token)
     namespace = params['namespace']
     headers = {'X-Vault-Token': token, 'X-Vault-Namespace': namespace}
     url = params['url']
