@@ -157,7 +157,7 @@ def hashivault_oidc_auth_role(module):
     current_state = dict()
     changed = False
 
-    token = params['token']
+    token = params.get('token', client.token)
     namespace = params['namespace']
     headers = {'X-Vault-Token': token, 'X-Vault-Namespace': namespace}
     url = params['url']
